Clojure only.

smile.association

Association Rule Mining

Association Rule Mining
raw docstring

armclj

(arm min-confidence tree)

Association rule mining.

min-confidence is the minimum confidence of rules. tree is the FP-tree.

Association rule mining.

`min-confidence` is the minimum confidence of rules.
`tree` is the FP-tree.
sourceraw docstring

fpgrowthclj

(fpgrowth min-support itemsets)

Frequent item set mining based on the FP-growth algorithm.

min-support is the required minimum support of item sets in terms of frequency. itemsets is the item set database. Each row is an item set, which may have different length. The item identifiers have to be in [0, n), where n is the number of items. Item set should NOT contain duplicated items.

Frequent item set mining based on the FP-growth algorithm.

`min-support` is the required minimum support of item sets in terms of frequency.
`itemsets` is the item set database. Each row is an item set, which may have
different length. The item identifiers have to be in [0, n), where n is the
number of items. Item set should NOT contain duplicated items.
sourceraw docstring

fptreeclj

(fptree min-support supplier)

Builds an FP-tree.

min-support is the required minimum support of item sets in terms of frequency. supplier is a supplier that returns a stream of item sets. Each item set may have different length. The item identifiers have to be in [0, n), where n is the number of items. Item set should NOT contain duplicated items.

Builds an FP-tree.

`min-support` is the required minimum support of item sets in terms of frequency.
`supplier` is a supplier that returns a stream of item sets. Each item set
may have different length. The item identifiers have to be in [0, n),
where n is the number of items. Item set should NOT contain duplicated items.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries